(* $Id: godi_file_handler.mli 708 2007-07-29 21:49:10Z gerd $ *)

open Godi_types

(* Query *)

(* Note URLs. We have a quite simple view on them:
 *
 * - /dir/dir/... is considered as a local file name
 * - scheme://authority/dir/dir/... is considered as a URL for a remote
 *   file.
 *
 * The directory of a given URL is determined by cutting of
 * "name" or "name/" at the end.
 * The authority component of remore URL is never cut off.
 * E.g.
 * - http://foo.com/dir/name has directory http://foo.com/dir/
 * - http://foo.com/dir/ has directory http://foo.com/
 * - http://foo.com/dir has directory http://foo.com/
 * - http://foo.com/ has no directory URL.
 *
 * URL escaping is totally ignored.
 *)

val handler_of_directory : string -> file_handler
  (* Returns the handler for a directory URL *)

val split_name : string -> (string * string)
  (* Splits the URL into a directory URL and a file name *)


(* Registry *)

(* A handler for local files is already registered *)

val register : string -> (string -> file_handler) -> unit
  (* Register a handler for a given scheme *)
